the_silo
========

.. image:: https://img.shields.io/pypi/l/the_silo.svg
    :target: https://pypi.python.org/pypi/the_silo
.. image:: https://img.shields.io/pypi/pyversions/the_silo.svg
    :target: https://pypi.python.org/pypi/the_silo
.. image:: https://img.shields.io/pypi/v/the_silo.svg
    :target: https://pypi.python.org/pypi/the_silo
.. image:: https://img.shields.io/pypi/wheel/the_silo.svg
    :target: https://pypi.python.org/pypi/the_silo
.. image:: https://readthedocs.org/projects/the-silo/badge/?version=latest
    :target: https://readthedocs.org/projects/the-silo/?badge=latest

The Silo is a collection of useful tools for Nuke.

`Full Documentation`_

Installation
------------

To install ``the_silo``, type:

.. code-block:: bash

    $ pip install the_silo

Open Nuke's ``init.py`` file and add:

.. code-block:: python

    nuke.pluginAddPath('/path/to/your/local/python/site-packages')

Open Nuke's ``menu.py`` file and add:

.. code-block:: python

    import the_silo

Getting Started
---------------

There are currently two categories of tools:

- Gizmos
- Scripts

Getting started is easy. After you have installed The Silo, all available tools
will be added to a menu called ``The Silo`` and sub-menus called ``Gizmos`` and
``Scripts``. That's it. :)

.. _Full Documentation: http://the-silo.readthedocs.io/en/latest/
